
Ferramenta DoS multithread em Python que inunda servidores Minecraft Java com pacotes de handshake forjados, reutilização de conexões, preenchimento de payload e falsificação de versão de protocolo.
JAVAFLOOD é uma ferramenta projetada para lançar ataques de Negação de Serviço (DoS) em servidores de Minecraft Java Edition. Esta ferramenta inunda o servidor com múltiplos métodos para sobrecarregar os recursos do servidor, resultando em um estado de não resposta.
Qualquer uso não autorizado, incluindo tentar interromper, sobrecarregar ou danificar servidores, é estritamente proibido e pode ser considerado ilegal sob as leis aplicáveis. Tais ações podem levar a consequências graves tanto para os sistemas alvo quanto para os indivíduos envolvidos.
Por favor, use esta ferramenta de forma responsável e apenas para testes de segurança legítimos e propósitos acadêmicos. O uso indevido desta ferramenta é antiético, potencialmente ilegal e fortemente desencorajado.
O desenvolvedor desta ferramenta a criou apenas para fins educacionais e de pesquisa dentro de um ambiente controlado e não assume qualquer responsabilidade por qualquer uso indevido, dano ou consequência legal resultante de uso intencional ou não autorizado por terceiros.
Inundação de Handshake TCP:
handshakes TCP para consumir os recursos de socket do servidor.Reutilização de Conexão:
conexão TCP para maximizar o impacto.Multithreading:
ThreadPoolExecutor para executar múltiplas threads para envio paralelo de pacotes.Sincronização de Threads:
daemon threadsAbuso do Protocolo Minecraft:
Preenchimento de Payload:
Loops Rápidos de Conexão-Desconexão:
Falsificação de Versão do Protocolo:
Verificar Status do Servidor:
python3 javaflood.py -api < IP/Domain >| Argumento | Obrigatório | Descrição |
|---|---|---|
| -ip | Sim | Define o endereço IP do servidor de destino (por exemplo, 127.0.0.1). |
| -port | Sim | Especifica a porta de destino (deve ser um número inteiro entre 1 e 65535). |
| -s | Sim | Configura o tamanho (em bytes) de cada pacote transmitido. |
| -t | Sim | Determina o número de threads de execução paralelas. |
| -p | Sim | Define a versão do protocolo a ser usada durante a execução. |
| -d | Sim | Controla o tempo total de execução (em segundos). |
| -api | Opcional | Chama a função da API do mcstatus com o domínio. |
| -load | Opcional | Carrega a configuração externa a partir de um caminho de arquivo JSON especificado. |
| -wait | Opcional | Atrasa a execução por um número especificado de segundos. |
| -art | Opcional | Alterna a visibilidade do logotipo (1 = mostrar, 0 = ocultar). |
| -h | Não | Mostra esta mensagem de ajuda e sai. |
Clone este repositório para a sua máquina local:
git clone https://github.com/Audrise/javaflood.git
cd javaflood
Instale as bibliotecas Python necessárias:
pip3 install -r requirements.txt
Execute o javaflood usando vários métodos, conforme abaixo:
python3 javaflood.py -ip 120.0.0.1 -port 25565 -s 100 -t 100 -p 47 -d 60 -wait 10 -art 0
ou você pode usar o parâmetro -load:
python3 javaflood.py -load config.json
Ao usar o parâmetro -load, você pode executar a ferramenta diretamente com a configuração definida dentro de um arquivo .json, sem a necessidade de inserir manualmente todos os parâmetros. Isso é particularmente útil para acelerar o processo de configuração e executar a ferramenta com configurações predefinidas.
python3 javaflood.py -load config.json
Isso carregará todos os parâmetros de config.json e executará a ferramenta.
Certifique-se de que o arquivo .json que você criar esteja formatado corretamente, com os parâmetros esperados pela ferramenta. Aqui está um exemplo de uma estrutura JSON válida para esta ferramenta:
{
"ip": "127.0.0.1",
"port": 25565,
"packet_size": 0,
"threads": 0,
"protocol": 0,
"duration": 0,
"wait": 60,
"art": 0
}